import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="mazepa",
    version="0.0.0.1",
    author="Sergiy Popovych",
    author_email="sergiy.popovich@gmail.com",
    description="A tool for scheduling tasks to AWS queue",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/supersergiy/mazepa",
    include_package_data=True,
    package_data={'': ['*.py']},
    install_requires=[
      'boto3',
      'taskqueue',
      'tenacity'
    ],
    packages=setuptools.find_packages(),
)
